@@ -3,6 +3,7 @@
 
 from __future__ import absolute_import
 
+from .cameras import CAMERAS_RGB_SPECTRAL_SENSITIVITIES
 from .colour_checkers import (
     COLOURCHECKERS,
     COLOURCHECKER_INDEXES_TO_NAMES_MAPPING,
@@ -10,6 +11,7 @@ from .colour_checkers import (
 from .displays import DISPLAYS_RGB_PRIMARIES
 
 __all__ = []
+__all__ += ['CAMERAS_RGB_SPECTRAL_SENSITIVITIES']
 __all__ += ['COLOURCHECKERS',
             'COLOURCHECKER_INDEXES_TO_NAMES_MAPPING',
             'COLOURCHECKERS_SPDS']
