@@ -28,7 +28,7 @@ The following *CIE* illuminants are available:
 
 See Also
 --------
-`Illuminants IPython Notebook
+`Illuminants Jupyter Notebook
 <http://nbviewer.jupyter.org/github/colour-science/colour-notebooks/\
 blob/master/notebooks/colorimetry/illuminants.ipynb>`_
 
@@ -54,7 +54,7 @@ from colour.colorimetry.spectrum import SpectralPowerDistribution
 from colour.utilities import CaseInsensitiveMapping
 
 __author__ = 'Colour Developers'
-__copyright__ = 'Copyright (C) 2013-2016 - Colour Developers'
+__copyright__ = 'Copyright (C) 2013-2017 - Colour Developers'
 __license__ = 'New BSD License - http://opensource.org/licenses/BSD-3-Clause'
 __maintainer__ = 'Colour Developers'
 __email__ = 'colour-science@googlegroups.com'
@@ -65,7 +65,7 @@ __all__ = ['ILLUMINANTS_RELATIVE_SPDS_DATA',
 
 # *CIE Illuminant D Series* *D60* relative spectral power distribution
 # has been calculated as follows:
-# xy = colour.ILLUMINANTS.get('CIE 1931 2 Degree Standard Observer').get('D60')
+# xy = colour.ILLUMINANTS['CIE 1931 2 Degree Standard Observer']['D60']
 # D65_illuminant_relative_spd = colour.D_illuminant_relative_spd(xy)
 # D65_illuminant_relative_spd.name = 'D60'
 ILLUMINANTS_RELATIVE_SPDS_DATA = {
@@ -3531,87 +3531,87 @@ ILLUMINANTS_RELATIVE_SPDS_DATA = {
 
 ILLUMINANTS_RELATIVE_SPDS = CaseInsensitiveMapping(
     {'A': SpectralPowerDistribution(
-        'A', ILLUMINANTS_RELATIVE_SPDS_DATA.get('A')),
+        'A', ILLUMINANTS_RELATIVE_SPDS_DATA['A']),
      'B': SpectralPowerDistribution(
-         'B', ILLUMINANTS_RELATIVE_SPDS_DATA.get('B')),
+         'B', ILLUMINANTS_RELATIVE_SPDS_DATA['B']),
      'C': SpectralPowerDistribution(
-         'C', ILLUMINANTS_RELATIVE_SPDS_DATA.get('C')),
+         'C', ILLUMINANTS_RELATIVE_SPDS_DATA['C']),
      'D50': SpectralPowerDistribution(
-         'D50', ILLUMINANTS_RELATIVE_SPDS_DATA.get('D50')),
+         'D50', ILLUMINANTS_RELATIVE_SPDS_DATA['D50']),
      'D55': SpectralPowerDistribution(
-         'D55', ILLUMINANTS_RELATIVE_SPDS_DATA.get('D55')),
+         'D55', ILLUMINANTS_RELATIVE_SPDS_DATA['D55']),
      'D60': SpectralPowerDistribution(
-         'D60', ILLUMINANTS_RELATIVE_SPDS_DATA.get('D60')),
+         'D60', ILLUMINANTS_RELATIVE_SPDS_DATA['D60']),
      'D65': SpectralPowerDistribution(
-         'D65', ILLUMINANTS_RELATIVE_SPDS_DATA.get('D65')),
+         'D65', ILLUMINANTS_RELATIVE_SPDS_DATA['D65']),
      'D75': SpectralPowerDistribution(
-         'D75', ILLUMINANTS_RELATIVE_SPDS_DATA.get('D75')),
+         'D75', ILLUMINANTS_RELATIVE_SPDS_DATA['D75']),
      'E': SpectralPowerDistribution(
-         'E', ILLUMINANTS_RELATIVE_SPDS_DATA.get('E')),
+         'E', ILLUMINANTS_RELATIVE_SPDS_DATA['E']),
      'F1': SpectralPowerDistribution(
-         'F1', ILLUMINANTS_RELATIVE_SPDS_DATA.get('F1')),
+         'F1', ILLUMINANTS_RELATIVE_SPDS_DATA['F1']),
      'F2': SpectralPowerDistribution(
-         'F2', ILLUMINANTS_RELATIVE_SPDS_DATA.get('F2')),
+         'F2', ILLUMINANTS_RELATIVE_SPDS_DATA['F2']),
      'F3': SpectralPowerDistribution(
-         'F3', ILLUMINANTS_RELATIVE_SPDS_DATA.get('F3')),
+         'F3', ILLUMINANTS_RELATIVE_SPDS_DATA['F3']),
      'F4': SpectralPowerDistribution(
-         'F4', ILLUMINANTS_RELATIVE_SPDS_DATA.get('F4')),
+         'F4', ILLUMINANTS_RELATIVE_SPDS_DATA['F4']),
      'F5': SpectralPowerDistribution(
-         'F5', ILLUMINANTS_RELATIVE_SPDS_DATA.get('F5')),
+         'F5', ILLUMINANTS_RELATIVE_SPDS_DATA['F5']),
      'F6': SpectralPowerDistribution(
-         'F6', ILLUMINANTS_RELATIVE_SPDS_DATA.get('F6')),
+         'F6', ILLUMINANTS_RELATIVE_SPDS_DATA['F6']),
      'F7': SpectralPowerDistribution(
-         'F7', ILLUMINANTS_RELATIVE_SPDS_DATA.get('F7')),
+         'F7', ILLUMINANTS_RELATIVE_SPDS_DATA['F7']),
      'F8': SpectralPowerDistribution(
-         'F8', ILLUMINANTS_RELATIVE_SPDS_DATA.get('F8')),
+         'F8', ILLUMINANTS_RELATIVE_SPDS_DATA['F8']),
      'F9': SpectralPowerDistribution(
-         'F9', ILLUMINANTS_RELATIVE_SPDS_DATA.get('F9')),
+         'F9', ILLUMINANTS_RELATIVE_SPDS_DATA['F9']),
      'F10': SpectralPowerDistribution(
-         'F10', ILLUMINANTS_RELATIVE_SPDS_DATA.get('F10')),
+         'F10', ILLUMINANTS_RELATIVE_SPDS_DATA['F10']),
      'F11': SpectralPowerDistribution(
-         'F11', ILLUMINANTS_RELATIVE_SPDS_DATA.get('F11')),
+         'F11', ILLUMINANTS_RELATIVE_SPDS_DATA['F11']),
      'F12': SpectralPowerDistribution(
-         'F12', ILLUMINANTS_RELATIVE_SPDS_DATA.get('F12')),
+         'F12', ILLUMINANTS_RELATIVE_SPDS_DATA['F12']),
      'FL3.1': SpectralPowerDistribution(
-         'FL3.1', ILLUMINANTS_RELATIVE_SPDS_DATA.get('FL3.1')),
+         'FL3.1', ILLUMINANTS_RELATIVE_SPDS_DATA['FL3.1']),
      'FL3.2': SpectralPowerDistribution(
-         'FL3.2', ILLUMINANTS_RELATIVE_SPDS_DATA.get('FL3.2')),
+         'FL3.2', ILLUMINANTS_RELATIVE_SPDS_DATA['FL3.2']),
      'FL3.3': SpectralPowerDistribution(
-         'FL3.3', ILLUMINANTS_RELATIVE_SPDS_DATA.get('FL3.3')),
+         'FL3.3', ILLUMINANTS_RELATIVE_SPDS_DATA['FL3.3']),
      'FL3.4': SpectralPowerDistribution(
-         'FL3.4', ILLUMINANTS_RELATIVE_SPDS_DATA.get('FL3.4')),
+         'FL3.4', ILLUMINANTS_RELATIVE_SPDS_DATA['FL3.4']),
      'FL3.5': SpectralPowerDistribution(
-         'FL3.5', ILLUMINANTS_RELATIVE_SPDS_DATA.get('FL3.5')),
+         'FL3.5', ILLUMINANTS_RELATIVE_SPDS_DATA['FL3.5']),
      'FL3.6': SpectralPowerDistribution(
-         'FL3.6', ILLUMINANTS_RELATIVE_SPDS_DATA.get('FL3.6')),
+         'FL3.6', ILLUMINANTS_RELATIVE_SPDS_DATA['FL3.6']),
      'FL3.7': SpectralPowerDistribution(
-         'FL3.7', ILLUMINANTS_RELATIVE_SPDS_DATA.get('FL3.7')),
+         'FL3.7', ILLUMINANTS_RELATIVE_SPDS_DATA['FL3.7']),
      'FL3.8': SpectralPowerDistribution(
-         'FL3.8', ILLUMINANTS_RELATIVE_SPDS_DATA.get('FL3.8')),
+         'FL3.8', ILLUMINANTS_RELATIVE_SPDS_DATA['FL3.8']),
      'FL3.9': SpectralPowerDistribution(
-         'FL3.9', ILLUMINANTS_RELATIVE_SPDS_DATA.get('FL3.9')),
+         'FL3.9', ILLUMINANTS_RELATIVE_SPDS_DATA['FL3.9']),
      'FL3.10': SpectralPowerDistribution(
-         'FL3.10', ILLUMINANTS_RELATIVE_SPDS_DATA.get('FL3.10')),
+         'FL3.10', ILLUMINANTS_RELATIVE_SPDS_DATA['FL3.10']),
      'FL3.11': SpectralPowerDistribution(
-         'FL3.11', ILLUMINANTS_RELATIVE_SPDS_DATA.get('FL3.11')),
+         'FL3.11', ILLUMINANTS_RELATIVE_SPDS_DATA['FL3.11']),
      'FL3.12': SpectralPowerDistribution(
-         'FL3.12', ILLUMINANTS_RELATIVE_SPDS_DATA.get('FL3.12')),
+         'FL3.12', ILLUMINANTS_RELATIVE_SPDS_DATA['FL3.12']),
      'FL3.13': SpectralPowerDistribution(
-         'FL3.13', ILLUMINANTS_RELATIVE_SPDS_DATA.get('FL3.13')),
+         'FL3.13', ILLUMINANTS_RELATIVE_SPDS_DATA['FL3.13']),
      'FL3.14': SpectralPowerDistribution(
-         'FL3.14', ILLUMINANTS_RELATIVE_SPDS_DATA.get('FL3.14')),
+         'FL3.14', ILLUMINANTS_RELATIVE_SPDS_DATA['FL3.14']),
      'FL3.15': SpectralPowerDistribution(
-         'FL3.15', ILLUMINANTS_RELATIVE_SPDS_DATA.get('FL3.15')),
+         'FL3.15', ILLUMINANTS_RELATIVE_SPDS_DATA['FL3.15']),
      'HP1': SpectralPowerDistribution(
-         'HP1', ILLUMINANTS_RELATIVE_SPDS_DATA.get('HP1')),
+         'HP1', ILLUMINANTS_RELATIVE_SPDS_DATA['HP1']),
      'HP2': SpectralPowerDistribution(
-         'HP2', ILLUMINANTS_RELATIVE_SPDS_DATA.get('HP2')),
+         'HP2', ILLUMINANTS_RELATIVE_SPDS_DATA['HP2']),
      'HP3': SpectralPowerDistribution(
-         'HP3', ILLUMINANTS_RELATIVE_SPDS_DATA.get('HP3')),
+         'HP3', ILLUMINANTS_RELATIVE_SPDS_DATA['HP3']),
      'HP4': SpectralPowerDistribution(
-         'HP4', ILLUMINANTS_RELATIVE_SPDS_DATA.get('HP4')),
+         'HP4', ILLUMINANTS_RELATIVE_SPDS_DATA['HP4']),
      'HP5': SpectralPowerDistribution(
-         'HP5', ILLUMINANTS_RELATIVE_SPDS_DATA.get('HP5'))})
+         'HP5', ILLUMINANTS_RELATIVE_SPDS_DATA['HP5'])})
 """
 *CIE* illuminants relative spectral power distributions.
 
