@@ -26,7 +26,7 @@ The following luminous efficiency functions are available:
 
 See Also
 --------
-`Luminous Efficiency Functions IPython Notebook
+`Luminous Efficiency Functions Jupyter Notebook
 <http://nbviewer.jupyter.org/github/colour-science/colour-notebooks/\
 blob/master/notebooks/colorimetry/lefs.ipynb>`_
 
@@ -59,7 +59,7 @@ from colour.colorimetry import SpectralPowerDistribution
 from colour.utilities import CaseInsensitiveMapping
 
 __author__ = 'Colour Developers'
-__copyright__ = 'Copyright (C) 2013-2016 - Colour Developers'
+__copyright__ = 'Copyright (C) 2013-2017 - Colour Developers'
 __license__ = 'New BSD License - http://opensource.org/licenses/BSD-3-Clause'
 __maintainer__ = 'Colour Developers'
 __email__ = 'colour-science@googlegroups.com'
@@ -2350,35 +2350,35 @@ PHOTOPIC_LEFS = CaseInsensitiveMapping(
     {'CIE 1924 Photopic Standard Observer':
         SpectralPowerDistribution(
             'CIE 1924 Photopic Standard Observer',
-            PHOTOPIC_LEFS_DATA.get(
-                'CIE 1924 Photopic Standard Observer')),
+            PHOTOPIC_LEFS_DATA[
+                'CIE 1924 Photopic Standard Observer']),
      'Judd Modified CIE 1951 Photopic Standard Observer':
          SpectralPowerDistribution(
              'Judd Modified CIE 1951 Photopic Standard Observer',
-             PHOTOPIC_LEFS_DATA.get(
-                 'Judd Modified CIE 1951 Photopic Standard Observer')),
+             PHOTOPIC_LEFS_DATA[
+                 'Judd Modified CIE 1951 Photopic Standard Observer']),
      'Judd-Vos Modified CIE 1978 Photopic Standard Observer':
          SpectralPowerDistribution(
              'Judd-Vos Modified CIE 1978 Photopic Standard Observer',
-             PHOTOPIC_LEFS_DATA.get(
-                 'Judd-Vos Modified CIE 1978 Photopic Standard Observer')),
+             PHOTOPIC_LEFS_DATA[
+                 'Judd-Vos Modified CIE 1978 Photopic Standard Observer']),
      'CIE 1964 Photopic 10 Degree Standard Observer':
          SpectralPowerDistribution(
              'CIE 1964 Photopic 10 Degree Standard Observer',
-             PHOTOPIC_LEFS_DATA.get(
-                 'CIE 1964 Photopic 10 Degree Standard Observer'),
+             PHOTOPIC_LEFS_DATA[
+                 'CIE 1964 Photopic 10 Degree Standard Observer'],
              'CIE 1964 Photopic 10$^\\circ$ Standard Observer'),
      'CIE 2008 2 Degree Physiologically Relevant LEF':
          SpectralPowerDistribution(
              'CIE 2008 2 Degree Physiologically Relevant LEF',
-             PHOTOPIC_LEFS_DATA.get(
-                 'CIE 2008 2 Degree Physiologically Relevant LEF'),
+             PHOTOPIC_LEFS_DATA[
+                 'CIE 2008 2 Degree Physiologically Relevant LEF'],
              'CIE 2008 2$^\\circ$ Physiologically Relevant LEF'),
      'CIE 2008 10 Degree Physiologically Relevant LEF':
          SpectralPowerDistribution(
              'CIE 2008 10 Degree Physiologically Relevant LEF',
-             PHOTOPIC_LEFS_DATA.get(
-                 'CIE 2008 10 Degree Physiologically Relevant LEF'),
+             PHOTOPIC_LEFS_DATA[
+                 'CIE 2008 10 Degree Physiologically Relevant LEF'],
              'CIE 2008 10$^\\circ$ Physiologically Relevant LEF')})
 """
 Photopic luminous efficiency functions.
@@ -2808,7 +2808,7 @@ SCOTOPIC_LEFS_DATA = {
 SCOTOPIC_LEFS = CaseInsensitiveMapping(
     {'CIE 1951 Scotopic Standard Observer': SpectralPowerDistribution(
         'CIE 1951 Scotopic Standard Observer',
-        SCOTOPIC_LEFS_DATA.get('CIE 1951 Scotopic Standard Observer'))})
+        SCOTOPIC_LEFS_DATA['CIE 1951 Scotopic Standard Observer'])})
 """
 Scotopic luminous efficiency functions.
 
