@@ -22,7 +22,7 @@ from colour.colorimetry.spectrum import (
 from colour.utilities import tstack
 
 __author__ = 'Colour Developers'
-__copyright__ = 'Copyright (C) 2013-2016 - Colour Developers'
+__copyright__ = 'Copyright (C) 2013-2017 - Colour Developers'
 __license__ = 'New BSD License - http://opensource.org/licenses/BSD-3-Clause'
 __maintainer__ = 'Colour Developers'
 __email__ = 'colour-science@googlegroups.com'
@@ -1784,87 +1784,87 @@ CIE_1931_2_DEGREE_STANDARD_OBSERVER = {
         780: 0.000000}}
 
 CMFS_DATA = {
-    380: (0.001368, 3.90e-05, 0.006450),
-    385: (0.002236, 6.40e-05, 0.010550),
-    390: (0.004243, 0.000120, 0.020050),
-    395: (0.007650, 0.000217, 0.036210),
-    400: (0.014310, 0.000396, 0.067850),
-    405: (0.023190, 0.000640, 0.110200),
-    410: (0.043510, 0.001210, 0.207400),
-    415: (0.077630, 0.002180, 0.371300),
-    420: (0.134380, 0.004000, 0.645600),
-    425: (0.214770, 0.007300, 1.039050),
-    430: (0.283900, 0.011600, 1.385600),
-    435: (0.328500, 0.016840, 1.622960),
-    440: (0.348280, 0.023000, 1.747060),
-    445: (0.348060, 0.029800, 1.782600),
-    450: (0.336200, 0.038000, 1.772110),
-    455: (0.318700, 0.048000, 1.744100),
-    460: (0.290800, 0.060000, 1.669200),
-    465: (0.251100, 0.073900, 1.528100),
-    470: (0.195360, 0.090980, 1.287640),
-    475: (0.142100, 0.112600, 1.041900),
-    480: (0.095640, 0.139020, 0.812950),
-    485: (0.057950, 0.169300, 0.616200),
-    490: (0.032010, 0.208020, 0.465180),
-    495: (0.014700, 0.258600, 0.353300),
-    500: (0.004900, 0.323000, 0.272000),
-    505: (0.002400, 0.407300, 0.212300),
-    510: (0.009300, 0.503000, 0.158200),
-    515: (0.029100, 0.608200, 0.111700),
-    520: (0.063270, 0.710000, 0.078250),
-    525: (0.109600, 0.793200, 0.057250),
-    530: (0.165500, 0.862000, 0.042160),
-    535: (0.225750, 0.914850, 0.029840),
-    540: (0.290400, 0.954000, 0.020300),
-    545: (0.359700, 0.980300, 0.013400),
-    550: (0.433450, 0.994950, 0.008750),
-    555: (0.512050, 1.000000, 0.005750),
-    560: (0.594500, 0.995000, 0.003900),
-    565: (0.678400, 0.978600, 0.002750),
-    570: (0.762100, 0.952000, 0.002100),
-    575: (0.842500, 0.915400, 0.001800),
-    580: (0.916300, 0.870000, 0.001650),
-    585: (0.978600, 0.816300, 0.001400),
-    590: (1.026300, 0.757000, 0.001100),
-    595: (1.056700, 0.694900, 0.001000),
-    600: (1.062200, 0.631000, 0.000800),
-    605: (1.045600, 0.566800, 0.000600),
-    610: (1.002600, 0.503000, 0.000340),
-    615: (0.938400, 0.441200, 0.000240),
-    620: (0.854450, 0.381000, 0.000190),
-    625: (0.751400, 0.321000, 0.000100),
-    630: (0.642400, 0.265000, 5.00e-05),
-    635: (0.541900, 0.217000, 3.00e-05),
-    640: (0.447900, 0.175000, 2.00e-05),
-    645: (0.360800, 0.138200, 1.00e-05),
-    650: (0.283500, 0.107000, 0.000000),
-    655: (0.218700, 0.081600, 0.000000),
-    660: (0.164900, 0.061000, 0.000000),
-    665: (0.121200, 0.044580, 0.000000),
-    670: (0.087400, 0.032000, 0.000000),
-    675: (0.063600, 0.023200, 0.000000),
-    680: (0.046770, 0.017000, 0.000000),
-    685: (0.032900, 0.011920, 0.000000),
-    690: (0.022700, 0.008210, 0.000000),
-    695: (0.015840, 0.005723, 0.000000),
-    700: (0.011359, 0.004102, 0.000000),
-    705: (0.008111, 0.002929, 0.000000),
-    710: (0.005790, 0.002091, 0.000000),
-    715: (0.004109, 0.001484, 0.000000),
-    720: (0.002899, 0.001047, 0.000000),
-    725: (0.002049, 0.000740, 0.000000),
-    730: (0.001440, 0.000520, 0.000000),
-    735: (0.001000, 0.000361, 0.000000),
-    740: (0.000690, 0.000249, 0.000000),
-    745: (0.000476, 0.000172, 0.000000),
-    750: (0.000332, 0.000120, 0.000000),
-    755: (0.000235, 8.50e-05, 0.000000),
-    760: (0.000166, 6.00e-05, 0.000000),
-    765: (0.000117, 4.20e-05, 0.000000),
-    770: (8.30e-05, 3.00e-05, 0.000000),
-    775: (5.90e-05, 2.10e-05, 0.000000),
-    780: (4.20e-05, 1.50e-05, 0.000000)}
+    380: np.array([0.001368, 3.90e-05, 0.006450]),
+    385: np.array([0.002236, 6.40e-05, 0.010550]),
+    390: np.array([0.004243, 0.000120, 0.020050]),
+    395: np.array([0.007650, 0.000217, 0.036210]),
+    400: np.array([0.014310, 0.000396, 0.067850]),
+    405: np.array([0.023190, 0.000640, 0.110200]),
+    410: np.array([0.043510, 0.001210, 0.207400]),
+    415: np.array([0.077630, 0.002180, 0.371300]),
+    420: np.array([0.134380, 0.004000, 0.645600]),
+    425: np.array([0.214770, 0.007300, 1.039050]),
+    430: np.array([0.283900, 0.011600, 1.385600]),
+    435: np.array([0.328500, 0.016840, 1.622960]),
+    440: np.array([0.348280, 0.023000, 1.747060]),
+    445: np.array([0.348060, 0.029800, 1.782600]),
+    450: np.array([0.336200, 0.038000, 1.772110]),
+    455: np.array([0.318700, 0.048000, 1.744100]),
+    460: np.array([0.290800, 0.060000, 1.669200]),
+    465: np.array([0.251100, 0.073900, 1.528100]),
+    470: np.array([0.195360, 0.090980, 1.287640]),
+    475: np.array([0.142100, 0.112600, 1.041900]),
+    480: np.array([0.095640, 0.139020, 0.812950]),
+    485: np.array([0.057950, 0.169300, 0.616200]),
+    490: np.array([0.032010, 0.208020, 0.465180]),
+    495: np.array([0.014700, 0.258600, 0.353300]),
+    500: np.array([0.004900, 0.323000, 0.272000]),
+    505: np.array([0.002400, 0.407300, 0.212300]),
+    510: np.array([0.009300, 0.503000, 0.158200]),
+    515: np.array([0.029100, 0.608200, 0.111700]),
+    520: np.array([0.063270, 0.710000, 0.078250]),
+    525: np.array([0.109600, 0.793200, 0.057250]),
+    530: np.array([0.165500, 0.862000, 0.042160]),
+    535: np.array([0.225750, 0.914850, 0.029840]),
+    540: np.array([0.290400, 0.954000, 0.020300]),
+    545: np.array([0.359700, 0.980300, 0.013400]),
+    550: np.array([0.433450, 0.994950, 0.008750]),
+    555: np.array([0.512050, 1.000000, 0.005750]),
+    560: np.array([0.594500, 0.995000, 0.003900]),
+    565: np.array([0.678400, 0.978600, 0.002750]),
+    570: np.array([0.762100, 0.952000, 0.002100]),
+    575: np.array([0.842500, 0.915400, 0.001800]),
+    580: np.array([0.916300, 0.870000, 0.001650]),
+    585: np.array([0.978600, 0.816300, 0.001400]),
+    590: np.array([1.026300, 0.757000, 0.001100]),
+    595: np.array([1.056700, 0.694900, 0.001000]),
+    600: np.array([1.062200, 0.631000, 0.000800]),
+    605: np.array([1.045600, 0.566800, 0.000600]),
+    610: np.array([1.002600, 0.503000, 0.000340]),
+    615: np.array([0.938400, 0.441200, 0.000240]),
+    620: np.array([0.854450, 0.381000, 0.000190]),
+    625: np.array([0.751400, 0.321000, 0.000100]),
+    630: np.array([0.642400, 0.265000, 5.00e-05]),
+    635: np.array([0.541900, 0.217000, 3.00e-05]),
+    640: np.array([0.447900, 0.175000, 2.00e-05]),
+    645: np.array([0.360800, 0.138200, 1.00e-05]),
+    650: np.array([0.283500, 0.107000, 0.000000]),
+    655: np.array([0.218700, 0.081600, 0.000000]),
+    660: np.array([0.164900, 0.061000, 0.000000]),
+    665: np.array([0.121200, 0.044580, 0.000000]),
+    670: np.array([0.087400, 0.032000, 0.000000]),
+    675: np.array([0.063600, 0.023200, 0.000000]),
+    680: np.array([0.046770, 0.017000, 0.000000]),
+    685: np.array([0.032900, 0.011920, 0.000000]),
+    690: np.array([0.022700, 0.008210, 0.000000]),
+    695: np.array([0.015840, 0.005723, 0.000000]),
+    700: np.array([0.011359, 0.004102, 0.000000]),
+    705: np.array([0.008111, 0.002929, 0.000000]),
+    710: np.array([0.005790, 0.002091, 0.000000]),
+    715: np.array([0.004109, 0.001484, 0.000000]),
+    720: np.array([0.002899, 0.001047, 0.000000]),
+    725: np.array([0.002049, 0.000740, 0.000000]),
+    730: np.array([0.001440, 0.000520, 0.000000]),
+    735: np.array([0.001000, 0.000361, 0.000000]),
+    740: np.array([0.000690, 0.000249, 0.000000]),
+    745: np.array([0.000476, 0.000172, 0.000000]),
+    750: np.array([0.000332, 0.000120, 0.000000]),
+    755: np.array([0.000235, 8.50e-05, 0.000000]),
+    760: np.array([0.000166, 6.00e-05, 0.000000]),
+    765: np.array([0.000117, 4.20e-05, 0.000000]),
+    770: np.array([8.30e-05, 3.00e-05, 0.000000]),
+    775: np.array([5.90e-05, 2.10e-05, 0.000000]),
+    780: np.array([4.20e-05, 1.50e-05, 0.000000])}
 
 
 class TestSpectralMapping(unittest.TestCase):
@@ -2580,7 +2580,7 @@ TriSpectralPowerDistribution.wavelengths` attribute.
 
         np.testing.assert_almost_equal(
             self._tri_spd.wavelengths,
-            sorted(CIE_1931_2_DEGREE_STANDARD_OBSERVER.get('x_bar')))
+            sorted(CIE_1931_2_DEGREE_STANDARD_OBSERVER['x_bar']))
 
     def test_values(self):
         """
@@ -2591,12 +2591,12 @@ TriSpectralPowerDistribution.values` attribute.
         np.testing.assert_almost_equal(
             self._tri_spd.values,
             tstack((
-                [v for k, v in sorted(CIE_1931_2_DEGREE_STANDARD_OBSERVER.get(
-                    'x_bar').items())],
-                [v for k, v in sorted(CIE_1931_2_DEGREE_STANDARD_OBSERVER.get(
-                    'y_bar').items())],
-                [v for k, v in sorted(CIE_1931_2_DEGREE_STANDARD_OBSERVER.get(
-                    'z_bar').items())])))
+                [v for k, v in sorted(
+                    CIE_1931_2_DEGREE_STANDARD_OBSERVER['x_bar'].items())],
+                [v for k, v in sorted(
+                    CIE_1931_2_DEGREE_STANDARD_OBSERVER['y_bar'].items())],
+                [v for k, v in sorted(
+                    CIE_1931_2_DEGREE_STANDARD_OBSERVER['z_bar'].items())])))
 
     def test_shape(self):
         """
@@ -2695,7 +2695,7 @@ TriSpectralPowerDistribution.__iter__` method.
 
         self.assertEqual(
             {key: tuple(value) for key, value in self._tri_spd},
-            CMFS_DATA)
+            {key: tuple(value) for key, value in CMFS_DATA.items()})
 
     def test__contains__(self):
         """
@@ -3012,7 +3012,7 @@ class TestConstantSpd(unittest.TestCase):
 
         self.assertEqual(spd[555], k)
 
-        self.assertEqual(spd[830], k)
+        self.assertEqual(spd[780], k)
 
 
 class TestZerosSpd(unittest.TestCase):
@@ -3029,11 +3029,11 @@ class TestZerosSpd(unittest.TestCase):
 
         spd = zeros_spd()
 
-        self.assertEqual(spd[360], 0.)
+        self.assertEqual(spd[360], 0)
 
-        self.assertEqual(spd[555], 0.)
+        self.assertEqual(spd[555], 0)
 
-        self.assertEqual(spd[830], 0.)
+        self.assertEqual(spd[780], 0)
 
 
 class TestOnes_spd(unittest.TestCase):
@@ -3050,11 +3050,11 @@ class TestOnes_spd(unittest.TestCase):
 
         spd = ones_spd()
 
-        self.assertEqual(spd[360], 1.)
+        self.assertEqual(spd[360], 1)
 
-        self.assertEqual(spd[555], 1.)
+        self.assertEqual(spd[555], 1)
 
-        self.assertEqual(spd[830], 1.)
+        self.assertEqual(spd[780], 1)
 
 
 if __name__ == '__main__':
