@@ -5,8 +5,6 @@
 Showcases colour rendition charts computations.
 """
 
-from __future__ import division, unicode_literals
-
 import numpy as np
 from pprint import pprint
 
@@ -27,19 +25,19 @@ print('\n')
 
 message_box(('"ColorChecker 2005" colour rendition chart chromaticity '
              'coordinates data:\n'
-             '\n\t("Patch Number", "Patch Name", "x", "y", "Y")'))
+             '\n\t("Patch Number", "Patch Name", "xyY")'))
 name, data, illuminant = colour.COLOURCHECKERS['ColorChecker 2005']
-for index, name, x, y, Y in data:
-    print(index, name, x, y, Y)
+for index, name, xyY in data:
+    print(index, name, xyY)
 
 print('\n')
 
 message_box(('Converting "ColorChecker 2005" colour rendition chart "CIE xyY" '
              'colourspace values to "sRGB" colourspace "RGB" values:\n'
              '\n\t("Patch Name", ["R", "G", "B"])'))
-for index, name, x, y, Y in data:
+for index, name, xyY in data:
     RGB = colour.XYZ_to_RGB(
-        colour.xyY_to_XYZ(np.array([x, y, Y])),
+        colour.xyY_to_XYZ(xyY),
         illuminant,
         colour.ILLUMINANTS[
             'CIE 1931 2 Degree Standard Observer']['D65'],
