@@ -5,8 +5,6 @@
 Showcases *Lightness* computations.
 """
 
-from __future__ import division, unicode_literals
-
 import numpy as np
 
 import colour
@@ -24,7 +22,7 @@ print('\n')
 
 Y = 10.08
 message_box(('Computing "Lightness" using '
-             'Glasser, Mckinney, Reilly and Schnelle (1958) method for '
+             '"Glasser, Mckinney, Reilly and Schnelle (1958)" method for '
              'given "luminance" value:\n'
              '\n\t{0}'.format(Y)))
 print(colour.lightness_Glasser1958(Y))
@@ -32,7 +30,7 @@ print(colour.lightness(Y, method='Glasser 1958'))
 
 print('\n')
 
-message_box(('Computing "Lightness" using Wyszecki (1963) method for '
+message_box(('Computing "Lightness" using "Wyszecki (1963)" method for '
              'given "luminance" value:\n'
              '\n\t{0}'.format(Y)))
 print(colour.lightness_Wyszecki1963(Y))
@@ -40,7 +38,7 @@ print(colour.lightness(Y, method='Wyszecki 1963'))
 
 print('\n')
 
-message_box(('Computing "Lightness" using CIE 1976 method for '
+message_box(('Computing "Lightness" using "CIE 1976" method for '
              'given "luminance" value:\n'
              '\n\t{0}'.format(Y)))
 print(colour.lightness_CIE1976(Y))
