@@ -5,8 +5,6 @@
 Showcases *Luminance* computations.
 """
 
-from __future__ import division, unicode_literals
-
 import colour
 
 from colour.utilities.verbose import message_box
@@ -15,7 +13,7 @@ message_box('"Luminance" Computations')
 
 V = 3.74629715
 message_box(('Computing "luminance" using '
-             'Newhall, Nickerson, and Judd (1943) method for given '
+             '"Newhall, Nickerson, and Judd (1943)" method for given '
              '"Munsell" value:\n'
              '\n\t{0}'.format(V)))
 print(colour.luminance_Newhall1943(V))
@@ -24,7 +22,7 @@ print(colour.luminance(V, method='Newhall 1943'))
 print('\n')
 
 L = 37.98562910
-message_box(('Computing "luminance" using CIE Lab (1976) method for given '
+message_box(('Computing "luminance" using "CIE 1976" method for given '
              '"Lightness":\n'
              '\n\t{0}'.format(L)))
 print(colour.luminance_CIE1976(L))
