@@ -5,14 +5,12 @@
 Showcases *Photometry* computations.
 """
 
-from __future__ import division, unicode_literals
-
 import colour
 from colour.utilities.verbose import message_box
 
 message_box('"Photometry" Computations')
 
-spd = colour.LIGHT_SOURCES_RELATIVE_SPDS.get('Neodimium Incandescent')
+spd = colour.LIGHT_SOURCES_RELATIVE_SPDS['Neodimium Incandescent']
 message_box(('Computing "Luminous Flux" for given spectral power '
              'distribution:\n'
              '\n\t{0}'.format(spd.name)))
