@@ -12,7 +12,7 @@ from colour.phenomenons import (
     scattering_cross_section)
 from colour.utilities.verbose import message_box
 
-message_box('Rayleigh Optical Depth Computations')
+message_box('"Rayleigh" Optical Depth Computations')
 
 wavelength = 555 * 10e-8
 message_box(('Computing the scattering cross section per molecule at given '
@@ -22,7 +22,7 @@ print(scattering_cross_section(wavelength))
 
 print('\n')
 
-message_box(('Computing the "Rayleigh Optical depth" as function of '
+message_box(('Computing the "Rayleigh" optical depth as function of '
              'wavelength in cm:\n'
              '\n\tWavelength: {0} cm'.format(wavelength)))
 print(rayleigh_optical_depth(wavelength))
