@@ -11,13 +11,15 @@ from colour.utilities.verbose import message_box
 
 message_box('Optical Phenomenons Plots')
 
-message_box(('Plotting a single "Rayleigh Scattering" spectral power '
+colour_plotting_defaults()
+
+message_box(('Plotting a single "Rayleigh" scattering spectral power '
              'distribution.'))
 single_rayleigh_scattering_spd_plot()
 
 print('\n')
 
-message_box(('Comparing multiple "Rayleigh Scattering" spectral power '
+message_box(('Comparing multiple "Rayleigh" scattering spectral power '
              'distributions with different CO_2 concentrations.'))
 name_template = 'Rayleigh Scattering - CO2: {0} ppm'
 rayleigh_spds = []
