@@ -3,42 +3,61 @@
 
 from __future__ import absolute_import
 
-from .rgb_colourspace import RGB_Colourspace
-from .rgb_colourspace import XYZ_to_RGB, RGB_to_XYZ
-from .rgb_colourspace import RGB_to_RGB
 from .derivation import (
     normalised_primary_matrix,
     chromatically_adapted_primaries,
     primaries_whitepoint,
     RGB_luminance_equation,
     RGB_luminance)
+from .rgb_colourspace import RGB_Colourspace
+from .rgb_colourspace import XYZ_to_RGB, RGB_to_XYZ
+from .rgb_colourspace import RGB_to_RGB_matrix, RGB_to_RGB
 from .transfer_functions import *  # noqa
 from . import transfer_functions
 from .dataset import *  # noqa
 from . import dataset
 from .common import XYZ_to_sRGB, sRGB_to_XYZ
 from .aces_it import spectral_to_aces_relative_exposure_values
+from .deprecated import (
+    RGB_to_HSV,
+    HSV_to_RGB,
+    RGB_to_HSL,
+    HSL_to_RGB,
+    RGB_to_CMY,
+    CMY_to_RGB,
+    CMY_to_CMYK,
+    CMYK_to_CMY)
 from .ycbcr import (
     YCBCR_WEIGHTS,
     RGB_to_YCbCr,
     YCbCr_to_RGB,
     RGB_to_YcCbcCrc,
     YcCbcCrc_to_RGB)
+from .ictcp import RGB_to_ICTCP, ICTCP_to_RGB
 
-__all__ = ['RGB_Colourspace']
+__all__ = ['normalised_primary_matrix',
+           'chromatically_adapted_primaries',
+           'primaries_whitepoint',
+           'RGB_luminance_equation',
+           'RGB_luminance']
+__all__ += ['RGB_Colourspace']
 __all__ += ['XYZ_to_RGB', 'RGB_to_XYZ']
-__all__ += ['RGB_to_RGB']
-__all__ += ['normalised_primary_matrix',
-            'chromatically_adapted_primaries',
-            'primaries_whitepoint',
-            'RGB_luminance_equation',
-            'RGB_luminance']
+__all__ += ['RGB_to_RGB_matrix', 'RGB_to_RGB']
 __all__ += transfer_functions.__all__
 __all__ += dataset.__all__
 __all__ += ['XYZ_to_sRGB', 'sRGB_to_XYZ']
 __all__ += ['spectral_to_aces_relative_exposure_values']
+__all__ += ['RGB_to_HSV',
+            'HSV_to_RGB',
+            'RGB_to_HSL',
+            'HSL_to_RGB',
+            'RGB_to_CMY',
+            'CMY_to_RGB',
+            'CMY_to_CMYK',
+            'CMYK_to_CMY']
 __all__ += ['YCBCR_WEIGHTS',
             'RGB_to_YCbCr',
             'YCbCr_to_RGB',
             'RGB_to_YcCbcCrc',
             'YcCbcCrc_to_RGB']
+__all__ += ['RGB_to_ICTCP', 'ICTCP_to_RGB']
