@@ -10,6 +10,7 @@ from __future__ import division, unicode_literals
 import pickle
 import numpy as np
 import unittest
+from copy import deepcopy
 from itertools import permutations
 
 from colour.models import (
@@ -17,6 +18,7 @@ from colour.models import (
     RGB_Colourspace,
     XYZ_to_RGB,
     RGB_to_XYZ,
+    RGB_to_RGB_matrix,
     RGB_to_RGB,
     normalised_primary_matrix,
     oetf_sRGB,
@@ -24,7 +26,7 @@ from colour.models import (
 from colour.utilities import ignore_numpy_errors
 
 __author__ = 'Colour Developers'
-__copyright__ = 'Copyright (C) 2013-2016 - Colour Developers'
+__copyright__ = 'Copyright (C) 2013-2017 - Colour Developers'
 __license__ = 'New BSD License - http://opensource.org/licenses/BSD-3-Clause'
 __maintainer__ = 'Colour Developers'
 __email__ = 'colour-science@googlegroups.com'
@@ -34,6 +36,7 @@ __all__ = ['TestRGB_COLOURSPACES',
            'TestRGB_Colourspace',
            'TestXYZ_to_RGB',
            'TestRGB_to_XYZ',
+           'TestRGB_to_RGB_matrix',
            'TestRGB_to_RGB']
 
 
@@ -52,6 +55,7 @@ class TestRGB_COLOURSPACES(unittest.TestCase):
 
         XYZ_r = np.array([0.5, 0.5, 0.5]).reshape((3, 1))
         for colourspace in RGB_COLOURSPACES.values():
+            # Instantiation transformation matrices.
             if colourspace.name in (
                     'ProPhoto RGB', 'ERIMM RGB', 'RIMM RGB', 'ROMM RGB'):
                 tolerance = 1e-3
@@ -59,7 +63,8 @@ class TestRGB_COLOURSPACES(unittest.TestCase):
                 tolerance = 1e-4
             elif colourspace.name in ('Adobe RGB (1998)',):
                 tolerance = 1e-5
-            elif colourspace.name in ('ALEXA Wide Gamut RGB', 'V-Gamut'):
+            elif colourspace.name in (
+                    'ALEXA Wide Gamut RGB', 'V-Gamut', 'REDWideGamutRGB'):
                 tolerance = 1e-6
             else:
                 tolerance = 1e-7
@@ -73,6 +78,17 @@ class TestRGB_COLOURSPACES(unittest.TestCase):
                                        atol=tolerance,
                                        verbose=False)
 
+            RGB = np.dot(colourspace.XYZ_to_RGB_matrix, XYZ_r)
+            XYZ = np.dot(colourspace.RGB_to_XYZ_matrix, RGB)
+            np.testing.assert_allclose(XYZ_r,
+                                       XYZ,
+                                       rtol=tolerance,
+                                       atol=tolerance,
+                                       verbose=False)
+
+            # Derived transformation matrices.
+            colourspace = deepcopy(colourspace)
+            colourspace.use_derived_transformation_matrices(True)
             RGB = np.dot(colourspace.XYZ_to_RGB_matrix, XYZ_r)
             XYZ = np.dot(colourspace.RGB_to_XYZ_matrix, RGB)
             np.testing.assert_almost_equal(XYZ_r, XYZ, decimal=7)
@@ -174,11 +190,72 @@ class TestRGB_Colourspace(unittest.TestCase):
                                'RGB_to_XYZ_matrix',
                                'XYZ_to_RGB_matrix',
                                'encoding_cctf',
-                               'decoding_cctf')
+                               'decoding_cctf',
+                               'use_derived_RGB_to_XYZ_matrix',
+                               'use_derived_XYZ_to_RGB_matrix')
 
         for attribute in required_attributes:
             self.assertIn(attribute, dir(RGB_Colourspace))
 
+    def test_required_methods(self):
+        """
+        Tests presence of required methods.
+        """
+
+        required_methods = ('use_derived_transformation_matrices',)
+
+        for method in required_methods:
+            self.assertIn(method, dir(RGB_Colourspace))
+
+    def test_use_derived_transformation_matrices(self):
+        """
+        Tests :func:`colour.models.rgb.rgb_colourspace.RGB_Colourspace.range.\
+use_derived_transformation_matrices` method.
+        """
+
+        p = np.array([0.73470, 0.26530, 0.00000, 1.00000, 0.00010, -0.07700])
+        whitepoint = np.array([0.32168, 0.33767])
+        RGB_to_XYZ_matrix = np.identity(3)
+        XYZ_to_RGB_matrix = np.identity(3)
+        colourspace = RGB_Colourspace(
+            'RGB Colourspace',
+            p,
+            whitepoint,
+            'D60',
+            RGB_to_XYZ_matrix,
+            XYZ_to_RGB_matrix)
+
+        np.testing.assert_array_equal(
+            colourspace.RGB_to_XYZ_matrix,
+            np.identity(3))
+        np.testing.assert_array_equal(
+            colourspace.XYZ_to_RGB_matrix,
+            np.identity(3))
+
+        self.assertTrue(colourspace.use_derived_transformation_matrices())
+
+        np.testing.assert_almost_equal(
+            colourspace.RGB_to_XYZ_matrix,
+            np.array([[0.95255240, 0.00000000, 0.00009368],
+                      [0.34396645, 0.72816610, -0.07213255],
+                      [0.00000000, 0.00000000, 1.00882518]]),
+            decimal=7)
+        np.testing.assert_almost_equal(
+            colourspace.XYZ_to_RGB_matrix,
+            np.array([[1.04981102, 0.00000000, -0.00009748],
+                      [-0.49590302, 1.37331305, 0.09824004],
+                      [0.00000000, 0.00000000, 0.99125202]]),
+            decimal=7)
+
+        colourspace.use_derived_RGB_to_XYZ_matrix = False
+        np.testing.assert_array_equal(
+            colourspace.RGB_to_XYZ_matrix,
+            np.identity(3))
+        colourspace.use_derived_XYZ_to_RGB_matrix = False
+        np.testing.assert_array_equal(
+            colourspace.XYZ_to_RGB_matrix,
+            np.identity(3))
+
 
 class TestXYZ_to_RGB(unittest.TestCase):
     """
@@ -388,6 +465,48 @@ class TestRGB_to_XYZ(unittest.TestCase):
             RGB_to_XYZ(RGB, W_R, W_T, M)
 
 
+class TestRGB_to_RGB_matrix(unittest.TestCase):
+    """
+    Defines :func:`colour.models.rgb.rgb_colourspace.RGB_to_RGB_matrix`
+    definition unit tests methods.
+    """
+
+    def test_RGB_to_RGB_matrix(self):
+        """
+        Tests :func:`colour.models.rgb.rgb_colourspace.RGB_to_RGB_matrix`
+        definition.
+        """
+
+        aces_2065_1_colourspace = RGB_COLOURSPACES['ACES2065-1']
+        aces_cg_colourspace = RGB_COLOURSPACES['ACEScg']
+        sRGB_colourspace = RGB_COLOURSPACES['sRGB']
+
+        np.testing.assert_almost_equal(
+            RGB_to_RGB_matrix(aces_2065_1_colourspace,
+                              sRGB_colourspace),
+            np.array([[2.52164943, -1.13688855, -0.38491759],
+                      [-0.27521355, 1.36970515, -0.09439245],
+                      [-0.01592501, -0.14780637, 1.16380582]]),
+            decimal=7)
+
+        np.testing.assert_almost_equal(
+            RGB_to_RGB_matrix(sRGB_colourspace,
+                              aces_2065_1_colourspace),
+            np.array([[0.43958564, 0.38392940, 0.17653274],
+                      [0.08953957, 0.81474984, 0.09568361],
+                      [0.01738718, 0.10873911, 0.87382059]]),
+            decimal=7)
+
+        np.testing.assert_almost_equal(
+            RGB_to_RGB_matrix(aces_2065_1_colourspace,
+                              aces_cg_colourspace,
+                              'Bradford'),
+            np.array([[1.45143932, -0.23651075, -0.21492857],
+                      [-0.07655377, 1.17622970, -0.09967593],
+                      [0.00831615, -0.00603245, 0.99771630]]),
+            decimal=7)
+
+
 class TestRGB_to_RGB(unittest.TestCase):
     """
     Defines :func:`colour.models.rgb.rgb_colourspace.RGB_to_RGB` definition
@@ -399,14 +518,14 @@ class TestRGB_to_RGB(unittest.TestCase):
         Tests :func:`colour.models.rgb.rgb_colourspace.RGB_to_RGB` definition.
         """
 
-        aces_2065_1_colourspace = RGB_COLOURSPACES.get('ACES2065-1')
-        sRGB_colourspace = RGB_COLOURSPACES.get('sRGB')
+        aces_2065_1_colourspace = RGB_COLOURSPACES['ACES2065-1']
+        sRGB_colourspace = RGB_COLOURSPACES['sRGB']
 
         np.testing.assert_almost_equal(
             RGB_to_RGB(np.array([0.35521588, 0.41000000, 0.24177934]),
                        aces_2065_1_colourspace,
                        sRGB_colourspace),
-            np.array([0.33653829, 0.44097338, 0.21512063]),
+            np.array([0.33654049, 0.44099674, 0.21512677]),
             decimal=7)
 
         np.testing.assert_almost_equal(
@@ -421,7 +540,28 @@ class TestRGB_to_RGB(unittest.TestCase):
                        aces_2065_1_colourspace,
                        sRGB_colourspace,
                        'Bradford'),
-            np.array([0.33699675, 0.44134608, 0.21431681]),
+            np.array([0.33699893, 0.44136948, 0.21432296]),
+            decimal=7)
+
+        aces_cg_colourspace = RGB_COLOURSPACES['ACEScg']
+        aces_cc_colourspace = RGB_COLOURSPACES['ACEScc']
+
+        np.testing.assert_almost_equal(
+            RGB_to_RGB(np.array([0.35521588, 0.41000000, 0.24177934]),
+                       aces_cg_colourspace,
+                       aces_cc_colourspace,
+                       apply_decoding_cctf=True,
+                       apply_encoding_cctf=True),
+            np.array([0.46956438, 0.48137533, 0.43788601]),
+            decimal=7)
+
+        np.testing.assert_almost_equal(
+            RGB_to_RGB(np.array([0.46956438, 0.48137533, 0.43788601]),
+                       aces_cc_colourspace,
+                       sRGB_colourspace,
+                       apply_decoding_cctf=True,
+                       apply_encoding_cctf=True),
+            np.array([0.60983062, 0.67896356, 0.50435764]),
             decimal=7)
 
     def test_n_dimensional_RGB_to_RGB(self):
@@ -430,10 +570,10 @@ class TestRGB_to_RGB(unittest.TestCase):
         n-dimensions support.
         """
 
-        aces_2065_1_colourspace = RGB_COLOURSPACES.get('ACES2065-1')
-        sRGB_colourspace = RGB_COLOURSPACES.get('sRGB')
+        aces_2065_1_colourspace = RGB_COLOURSPACES['ACES2065-1']
+        sRGB_colourspace = RGB_COLOURSPACES['sRGB']
         RGB_i = np.array([0.35521588, 0.41000000, 0.24177934])
-        RGB_o = np.array([0.33653829, 0.44097338, 0.21512063])
+        RGB_o = np.array([0.33654049, 0.44099674, 0.21512677])
         np.testing.assert_almost_equal(
             RGB_to_RGB(RGB_i, aces_2065_1_colourspace, sRGB_colourspace),
             RGB_o,
@@ -460,8 +600,8 @@ class TestRGB_to_RGB(unittest.TestCase):
         nan support.
         """
 
-        aces_2065_1_colourspace = RGB_COLOURSPACES.get('ACES2065-1')
-        sRGB_colourspace = RGB_COLOURSPACES.get('sRGB')
+        aces_2065_1_colourspace = RGB_COLOURSPACES['ACES2065-1']
+        sRGB_colourspace = RGB_COLOURSPACES['sRGB']
 
         cases = [-1.0, 0.0, 1.0, -np.inf, np.inf, np.nan]
         cases = set(permutations(cases * 3, r=3))
